@@ -1,12 +1,7 @@
 package Task::BeLike::GENEHACK;
-BEGIN {
-  $Task::BeLike::GENEHACK::VERSION = '0.2';
-}
-BEGIN {
-  $Task::BeLike::GENEHACK::AUTHORITY = 'cpan:GENEHACK';
-}
+our $AUTHORITY = 'cpan:GENEHACK';
 # ABSTRACT: individuality via conformity
-
+$Task::BeLike::GENEHACK::VERSION = '0.3';
 use strict;
 use warnings;
 use 5.010;
@@ -15,15 +10,18 @@ use 5.010;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Task::BeLike::GENEHACK - individuality via conformity
 
 =head1 VERSION
 
-version 0.2
+version 0.3
 
 =head1 TASK CONTENTS
 
@@ -147,14 +145,13 @@ version 0.2
 
 =head1 AUTHOR
 
-John SJ Anderson <genehack@genehack.org>
+John SJ Anderson <john@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by John SJ Anderson.
+This software is copyright (c) 2020 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
